"use strict";

require("core-js/modules/web.dom.iterable");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _baseMap = require("@opentripplanner/base-map");

var _coreUtils = _interopRequireDefault(require("@opentripplanner/core-utils"));

var _fromToLocationPicker = _interopRequireDefault(require("@opentripplanner/from-to-location-picker"));

var _stopsOverlay = require("@opentripplanner/stops-overlay");

var _leaflet = require("leaflet");

var _react = _interopRequireWildcard(require("react"));

var _server = _interopRequireDefault(require("react-dom/server"));

var _reactRedux = require("react-redux");

var _reactLeaflet = require("react-leaflet");

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _reactIntl = require("react-intl");

var mapActions = _interopRequireWildcard(require("../../actions/map"));

var uiActions = _interopRequireWildcard(require("../../actions/ui"));

var _viewer = require("../../util/viewer");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const {
  getTextWidth
} = _coreUtils.default.itinerary;
const {
  ViewStopButton
} = _stopsOverlay.Styled;
const BaseStopIcon = _styledComponents.default.div`
  background: #fff;
  border: ${props => props.active ? '#000 3px' : '#333 1px'} solid;
  border-radius: 17px;
  color: #000;
  font-size: 16px;
  font-weight: bold;
  height: 12px;
  line-height: 0px;
  padding-left: 7px;
  padding-top: 12px;
  width: ${props => `${props.width || 12}px`}
`;

class EnhancedStopMarker extends _react.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "onClickView", () => {
      const {
        setViewedStop,
        stop
      } = this.props;
      setViewedStop({
        stopId: stop.id
      });
    });

    _defineProperty(this, "onFromClick", () => {
      this.setLocation('from');
    });

    _defineProperty(this, "onToClick", () => {
      this.setLocation('to');
    });
  }

  setLocation(locationType) {
    const {
      setLocation,
      stop
    } = this.props;
    const {
      lat,
      lon,
      name
    } = stop;
    setLocation({
      location: {
        lat,
        lon,
        name
      },
      locationType
    });
  }

  render() {
    var _stop$routes;

    const {
      activeStopId,
      fillColor,
      languageConfig,
      stop
    } = this.props;
    const {
      code,
      id,
      lat,
      lon,
      name
    } = stop;
    const [, stopId] = id.split(':');
    const stopCode = code || stopId;
    const routeShortNames = (_stop$routes = stop.routes) === null || _stop$routes === void 0 ? void 0 : _stop$routes.map(r => r.shortName).join(' ');
    const stopLabel = routeShortNames || '';
    if (!stopLabel) return null;
    const width = getTextWidth(stopLabel) * 0.83 + 80 / getTextWidth(stopLabel);
    const icon = (0, _leaflet.divIcon)({
      className: '',
      html: _server.default.renderToStaticMarkup( /*#__PURE__*/_react.default.createElement(BaseStopIcon, {
        active: id === activeStopId // Show actual stop name on hover for easy identification.
        ,
        style: {
          backgroundColor: fillColor
        },
        title: (0, _viewer.getStopName)(stop),
        width: width
      }, stopLabel)),
      iconAnchor: [width / 2, 10]
    });
    return /*#__PURE__*/_react.default.createElement(_reactLeaflet.Marker, {
      icon: icon,
      position: [lat, lon]
    }, /*#__PURE__*/_react.default.createElement(_reactLeaflet.Popup, null, /*#__PURE__*/_react.default.createElement(_baseMap.Styled.MapOverlayPopup, null, /*#__PURE__*/_react.default.createElement(_baseMap.Styled.PopupTitle, null, name), /*#__PURE__*/_react.default.createElement(_baseMap.Styled.PopupRow, null, /*#__PURE__*/_react.default.createElement("span", null, /*#__PURE__*/_react.default.createElement("b", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.EnhancedStopMarker.stopID"
    })), " ", stopCode), /*#__PURE__*/_react.default.createElement(ViewStopButton, {
      onClick: this.onClickView
    }, languageConfig.stopViewer || /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.EnhancedStopMarker.stopViewer"
    }))), /*#__PURE__*/_react.default.createElement(_baseMap.Styled.PopupRow, null, /*#__PURE__*/_react.default.createElement("b", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.EnhancedStopMarker.planATrip"
    })), /*#__PURE__*/_react.default.createElement(_fromToLocationPicker.default, {
      onFromClick: this.onFromClick,
      onToClick: this.onToClick
    })))));
  }

}

const mapStateToProps = (state, ownProps) => {
  var _state$otp$transitInd;

  const {
    highlightedStop,
    viewedRoute
  } = state.otp.ui;
  const routeData = viewedRoute && ((_state$otp$transitInd = state.otp.transitIndex.routes) === null || _state$otp$transitInd === void 0 ? void 0 : _state$otp$transitInd[viewedRoute.routeId]);
  const hoverColor = (routeData === null || routeData === void 0 ? void 0 : routeData.routeColor) || '#333';
  return {
    activeStopId: state.otp.ui.viewedStop.stopId,
    fillColor: highlightedStop === ownProps.entity.id ? hoverColor : '#FFF',
    languageConfig: state.otp.config.language,
    stop: ownProps.entity
  };
};

const mapDispatchToProps = {
  setLocation: mapActions.setLocation,
  setViewedStop: uiActions.setViewedStop
};

var _default = (0, _reactRedux.connect)(mapStateToProps, mapDispatchToProps)(EnhancedStopMarker);

exports.default = _default;
module.exports = exports.default;

//# sourceMappingURL=enhanced-stop-marker.js