"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("core-js/modules/web.dom.iterable");

var _formik = require("formik");

var _react = _interopRequireWildcard(require("react"));

var _reactBootstrap = require("react-bootstrap");

var _reactIntl = require("react-intl");

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _icon = _interopRequireDefault(require("../../util/icon"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

// Element styles
const SettingsList = _styledComponents.default.ul`
  border-spacing: 0 10px;
  display: table;
  padding-left: 0;
  width: 100%;
  label {
    font-weight: inherit;
  }
  & > li {
    align-items: center;
    display: block;
  }
`; // Using table display for this element, so that all dropdowns occupy the same width.
// (Bootstrap already sets them to occupy 100% of the width of the parent, i.e. the logical cell.)

const SettingsListWithAlign = (0, _styledComponents.default)(SettingsList)`
  & > li {
    display: table-row;
    & > * {
      display: table-cell;
    }
    & > label {
      padding-right: 10px;
    }
  }
`;
const InlineFormControl = (0, _styledComponents.default)(_reactBootstrap.FormControl)`
  display: inline-block;
  margin: 0 0.5em;
  width: auto;
`;
const SettingsToggle = _styledComponents.default.button`
  background: none;
  border: none;
  padding: 0;
  & span.fa {
    line-height: 150%;
  }
`;
/**
 * A label followed by a dropdown control.
 */

const Select = ({
  children,
  Control = _reactBootstrap.FormControl,
  label,
  name
}) =>
/*#__PURE__*/
// <Field> is kept outside of <label> to accommodate layout in table/grid cells.
_react.default.createElement(_react.default.Fragment, null, label && /*#__PURE__*/_react.default.createElement("label", {
  htmlFor: name
}, label), /*#__PURE__*/_react.default.createElement(_formik.Field, {
  as: Control,
  componentClass: "select",
  id: name,
  name: name
}, children));

function Options({
  defaultValue,
  options
}) {
  // <FormattedMessage> can't be used inside <option>.
  const intl = (0, _reactIntl.useIntl)();
  return options.map(({
    text,
    value
  }, i) => /*#__PURE__*/_react.default.createElement("option", {
    key: i,
    value: value
  }, value === defaultValue ? intl.formatMessage({
    id: 'common.forms.defaultValue'
  }, {
    value: text
  }) : text));
}

const basicYesNoOptions = [{
  id: 'yes',
  value: true
}, {
  id: 'no',
  value: false
}];
/**
 * Produces a yes/no list of options with the specified
 * default value (true for yes, false for no).
 */

function YesNoOptions({
  defaultValue
}) {
  // <FormattedMessage> can't be used inside <option>.
  const intl = (0, _reactIntl.useIntl)();
  const options = basicYesNoOptions.map(({
    id,
    value
  }) => ({
    text: id === 'yes' ? intl.formatMessage({
      id: `common.forms.yes`
    }) : intl.formatMessage({
      id: `common.forms.no`
    }),
    value
  }));
  return /*#__PURE__*/_react.default.createElement(Options, {
    defaultValue: defaultValue,
    options: options
  });
}
/**
 * Produces a list of duration options with the specified default value.
 */


function DurationOptions({
  defaultValue,
  minuteOptions
}) {
  // <FormattedMessage> can't be used inside <option>.
  const intl = (0, _reactIntl.useIntl)();
  const options = minuteOptions.map(minutes => ({
    text: minutes === 60 ? intl.formatMessage({
      id: 'components.TripNotificationsPane.oneHour'
    }, {
      minutes
    }) : intl.formatMessage({
      id: 'common.time.tripDurationFormatZeroHours'
    }, {
      minutes
    }),
    value: minutes
  }));
  return /*#__PURE__*/_react.default.createElement(Options, {
    defaultValue: defaultValue,
    options: options
  });
}
/**
 * This component wraps the elements to edit trip notification settings.
 */


class TripNotificationsPane extends _react.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "state", {
      showAdvancedSettings: false
    });

    _defineProperty(this, "_handleToggleAdvancedSettings", () => {
      this.setState({
        showAdvancedSettings: !this.state.showAdvancedSettings
      });
    });

    _defineProperty(this, "_handleDelayThresholdChange", e => {
      // To spare users the complexity of the departure/arrival delay thresholds,
      // set both the arrival and departure variance delays to the selected value.
      const {
        setFieldValue
      } = this.props;
      const threshold = e.target.value;
      setFieldValue('arrivalVarianceMinutesThreshold', threshold);
      setFieldValue('departureVarianceMinutesThreshold', threshold);
    });
  }

  render() {
    const {
      notificationChannel,
      values
    } = this.props;
    const areNotificationsDisabled = notificationChannel === 'none'; // Define a common trip delay field for simplicity, set to the smallest between the
    // retrieved departure/arrival delay attributes.

    const commonDelayThreshold = Math.min(values.arrivalVarianceMinutesThreshold, values.departureVarianceMinutesThreshold);
    let notificationSettingsContent;

    if (areNotificationsDisabled) {
      notificationSettingsContent = /*#__PURE__*/_react.default.createElement(_reactBootstrap.Alert, {
        bsStyle: "warning"
      }, /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_icon.default, {
        name: "alert",
        withSpace: true
      }), /*#__PURE__*/_react.default.createElement("strong", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.TripNotificationsPane.notificationsTurnedOff"
      }))), /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.TripNotificationsPane.howToReceiveAlerts"
      })));
    } else {
      const {
        showAdvancedSettings
      } = this.state;
      notificationSettingsContent = /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("h4", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.TripNotificationsPane.notifyViaChannelWhen",
        values: notificationChannel === 'email' ? {
          channel: /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
            id: "common.notifications.email"
          })
        } : {
          channel: /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
            id: "common.notifications.sms"
          })
        }
      })), /*#__PURE__*/_react.default.createElement(SettingsListWithAlign, null, /*#__PURE__*/_react.default.createElement("li", null, /*#__PURE__*/_react.default.createElement(Select, {
        label: /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
          id: "components.TripNotificationsPane.realtimeAlertFlagged"
        }),
        name: "notifyOnAlert"
      }, /*#__PURE__*/_react.default.createElement(YesNoOptions, {
        defaultValue: true
      }))), /*#__PURE__*/_react.default.createElement("li", null, /*#__PURE__*/_react.default.createElement(Select, {
        label: /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
          id: "components.TripNotificationsPane.altRouteRecommended"
        }),
        name: "notifyOnItineraryChange"
      }, /*#__PURE__*/_react.default.createElement(YesNoOptions, {
        defaultValue: true
      }))), /*#__PURE__*/_react.default.createElement("li", null, /*#__PURE__*/_react.default.createElement("label", {
        htmlFor: "commonDelayThreshold"
      }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.TripNotificationsPane.delaysAboveThreshold"
      })), /*#__PURE__*/_react.default.createElement(_reactBootstrap.FormControl, {
        componentClass: "select",
        id: "commonDelayThreshold" // Special event handler, hence not using <Select> as above.
        ,
        onChange: this._handleDelayThresholdChange,
        value: commonDelayThreshold
      }, /*#__PURE__*/_react.default.createElement(DurationOptions, {
        defaultValue: 5,
        minuteOptions: [5, 10, 15]
      })))), /*#__PURE__*/_react.default.createElement("h4", null, /*#__PURE__*/_react.default.createElement(SettingsToggle, {
        "aria-expanded": showAdvancedSettings,
        "aria-label": "Toggle advanced settings",
        onClick: this._handleToggleAdvancedSettings,
        type: "button"
      }, /*#__PURE__*/_react.default.createElement(_icon.default, {
        type: showAdvancedSettings ? 'caret-down' : 'caret-right'
      }), /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.TripNotificationsPane.advancedSettings"
      }))), showAdvancedSettings && /*#__PURE__*/_react.default.createElement(SettingsList, null, /*#__PURE__*/_react.default.createElement("li", null, /*#__PURE__*/_react.default.createElement("label", {
        htmlFor: "leadTimeInMinutes"
      }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.TripNotificationsPane.monitorThisTrip",
        values: {
          minutes: /*#__PURE__*/_react.default.createElement(Select, {
            Control: InlineFormControl,
            name: "leadTimeInMinutes"
          }, /*#__PURE__*/_react.default.createElement(DurationOptions, {
            defaultValue: 30,
            minuteOptions: [15, 30, 45, 60]
          }))
        }
      })))));
    }

    return /*#__PURE__*/_react.default.createElement("div", null, notificationSettingsContent);
  }

}

var _default = TripNotificationsPane;
exports.default = _default;
module.exports = exports.default;

//# sourceMappingURL=trip-notifications-pane.js