"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = activeTripRenderer;

var _react = _interopRequireDefault(require("react"));

var _reactIntl = require("react-intl");

var _viewer = require("../../../../util/viewer");

var _formattedDuration = _interopRequireDefault(require("../../../util/formatted-duration"));

var _baseRenderer = _interopRequireDefault(require("./base-renderer"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Calculates various data for monitored trips that are currently active.
 */
function activeTripRenderer({
  monitoredTrip,
  onTimeThresholdSeconds,
  timeFormat
}) {
  const data = (0, _baseRenderer.default)(monitoredTrip); // analyze whether the journey state indicates that the matching itinerary
  // has realtime data. It is assumed that realtime data will exist for
  // itineraries that have differing values of the scheduled arrival time
  // and matching itinerary arrival time.

  if (data.journeyState.hasRealtimeData) {
    // calculate the deviation from the scheduled arrival time (positive
    // value indicates delay)
    const arrivalDeviationSeconds = (data.matchingItinerary.endTime - data.journeyState.scheduledArrivalTimeEpochMillis) / 1000;
    const tripStatus = (0, _viewer.getTripStatus)(true, arrivalDeviationSeconds, onTimeThresholdSeconds);

    if (tripStatus === _viewer.REALTIME_STATUS.ON_TIME) {
      // about on time
      data.panelBsStyle = 'success';
      data.headingText = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.TripStatusRenderers.active.onTimeHeading"
      });
    } else if (tripStatus === _viewer.REALTIME_STATUS.LATE) {
      // delayed
      data.panelBsStyle = 'warning';
      data.headingText = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.TripStatusRenderers.active.delayedHeading",
        values: {
          formattedDuration: /*#__PURE__*/_react.default.createElement(_formattedDuration.default, {
            values: Math.abs(arrivalDeviationSeconds)
          })
        }
      });
    } else {
      // early
      data.panelBsStyle = 'warning';
      data.headingText = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: "components.TripStatusRenderers.active.earlyHeading",
        values: {
          formattedDuration: /*#__PURE__*/_react.default.createElement(_formattedDuration.default, {
            values: Math.abs(arrivalDeviationSeconds)
          })
        }
      });
    }
  } else {
    data.panelBsStyle = 'info';
    data.headingText = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.TripStatusRenderers.active.noDataHeading"
    });
  }

  data.bodyText = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
    id: "components.TripStatusRenderers.active.description",
    values: {
      arrivalTime: data.matchingItinerary.endTime
    }
  });
  data.shouldRenderTogglePauseTripButton = true;
  data.shouldRenderToggleSnoozeTripButton = true;
  return data;
}

module.exports = exports.default;

//# sourceMappingURL=active-trip-renderer.js