"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactIntl = require("react-intl");

var _viewer = require("../../util/viewer");

var _stopTimeCell = _interopRequireDefault(require("./stop-time-cell"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Shows the next arrival for a pattern within the related stops view.
 */
function NextArrivalForPattern(props) {
  const {
    homeTimezone,
    intl,
    pattern,
    route,
    stopTimes,
    stopViewerArriving,
    stopViewerConfig,
    timeFormat
  } = props; // sort stop times by next departure

  let sortedStopTimes = [];
  const hasStopTimes = stopTimes && stopTimes.length > 0;

  if (hasStopTimes) {
    sortedStopTimes = stopTimes.concat().sort(_viewer.stopTimeComparator) // We request only x departures per pattern, but the patterns are merged
    // according to shared headsigns, so we need to slice the stop times
    // here as well to ensure only x times are shown per route/headsign combo.
    // This is applied after the sort, so we're keeping the soonest departures.
    .slice(0, stopViewerConfig.numberOfDepartures);
  } else {
    // Do not render pattern row if it has no stop times.
    return null;
  }

  const routeName = route.shortName ? route.shortName : route.longName; // Splitting on the route name allows us to remove the route name from head sign,
  // should the GTFS include it

  let headsign = (0, _viewer.extractHeadsignFromPattern)(pattern).split(`${routeName} `); // If the route name is not embedded, this will select the single element.
  // If the route name is embedded, this will select only the second component

  headsign = headsign[headsign.length - 1];
  const toHeadsign = intl.formatMessage({
    id: 'components.LiveStopTimes.routeToHeadsign'
  }, {
    headsign
  });
  const title = `${routeName} ${toHeadsign}`;
  return /*#__PURE__*/_react.default.createElement("div", {
    className: "next-arrival-row"
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: "next-arrival-label overflow-ellipsis",
    title: title
  }, /*#__PURE__*/_react.default.createElement("span", {
    className: "route-name"
  }, routeName), toHeadsign), hasStopTimes && /*#__PURE__*/_react.default.createElement("div", {
    className: "next-arrival-time"
  }, /*#__PURE__*/_react.default.createElement(_stopTimeCell.default, {
    homeTimezone: homeTimezone,
    soonText: stopViewerArriving,
    stopTime: sortedStopTimes[0],
    timeFormat: timeFormat
  })));
}

var _default = (0, _reactIntl.injectIntl)(NextArrivalForPattern);

exports.default = _default;
module.exports = exports.default;

//# sourceMappingURL=next-arrival-for-pattern.js