"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.dayFieldsToArray = dayFieldsToArray;
exports.arrayToDayFields = arrayToDayFields;
exports.getFormattedDayOfWeekPlural = getFormattedDayOfWeekPlural;
exports.ALL_DAYS = exports.WEEKEND_DAYS = exports.WEEKDAYS = void 0;
const WEEKDAYS = ['monday', 'tuesday', 'wednesday', 'thursday', 'friday'];
exports.WEEKDAYS = WEEKDAYS;
const WEEKEND_DAYS = ['saturday', 'sunday'];
exports.WEEKEND_DAYS = WEEKEND_DAYS;
const ALL_DAYS = [...WEEKDAYS, ...WEEKEND_DAYS];
/**
 * Extracts the day of week fields of an object (e.g. a monitoredTrip) to an array.
 * Example: { monday: truthy, tuesday: falsy, wednesday: truthy ... } => ['monday', 'wednesday' ...]
 */

exports.ALL_DAYS = ALL_DAYS;

function dayFieldsToArray(monitoredTrip) {
  return ALL_DAYS.filter(day => monitoredTrip[day]);
}
/**
 * Converts an array of day of week values into an object with those fields.
 * Example: ['monday', 'wednesday' ...] => { monday: true, tuesday: false, wednesday: true ... }
 */


function arrayToDayFields(arrayOfDayTypes) {
  const result = {};
  ALL_DAYS.forEach(day => {
    result[day] = arrayOfDayTypes.includes(day);
  });
  return result;
}
/**
 * Returns a FormattedMessage string for the pluralised day of week via the react-intl imperative API
 * such that i18n IDs are hardcoded and can be kept track of by format.js tools
 */


function getFormattedDayOfWeekPlural(day, intl) {
  switch (day) {
    case 'monday':
      return intl.formatMessage({
        id: 'common.daysOfWeekPlural.monday'
      });

    case 'tuesday':
      return intl.formatMessage({
        id: 'common.daysOfWeekPlural.tuesday'
      });

    case 'wednesday':
      return intl.formatMessage({
        id: 'common.daysOfWeekPlural.wednesday'
      });

    case 'thursday':
      return intl.formatMessage({
        id: 'common.daysOfWeekPlural.thursday'
      });

    case 'friday':
      return intl.formatMessage({
        id: 'common.daysOfWeekPlural.friday'
      });

    case 'saturday':
      return intl.formatMessage({
        id: 'common.daysOfWeekPlural.saturday'
      });

    case 'sunday':
      return intl.formatMessage({
        id: 'common.daysOfWeekPlural.sunday'
      });

    default:
      return null;
  }
}

//# sourceMappingURL=monitored-trip.js